kg_set_secret_key
=================
This command is use for reseting the secret key in
``/etc/karaage3/settings.py``.

Description
-----------
To reset the secret key, run this command without any parameters:

.. code-block:: bash

   kg_set_secret_key
